diff --git a/ASLUAV/version.h b/ASLUAV/version.h
index 16588a2dc..0ac59e7b8 100644
--- a/ASLUAV/version.h
+++ b/ASLUAV/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/ardupilotmega/version.h b/ardupilotmega/version.h
index 981cdc79a..23dfc49b5 100644
--- a/ardupilotmega/version.h
+++ b/ardupilotmega/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/autoquad/version.h b/autoquad/version.h
index 4826d22bf..b3c34f94d 100644
--- a/autoquad/version.h
+++ b/autoquad/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/version.h b/common/version.h
index bfc6368fc..5b81125cb 100644
--- a/common/version.h
+++ b/common/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/icarous/version.h b/icarous/version.h
index 972530608..0b99bd413 100644
--- a/icarous/version.h
+++ b/icarous/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/matrixpilot/version.h b/matrixpilot/version.h
index 1259fedbd..7ba8566b7 100644
--- a/matrixpilot/version.h
+++ b/matrixpilot/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/message_definitions/common.xml b/message_definitions/common.xml
index 9562212b7..26c386cab 100644
--- a/message_definitions/common.xml
+++ b/message_definitions/common.xml
@@ -4629,11 +4629,11 @@
Estimate reset counter. This should be incremented when the estimate resets in any of the dimensions (position, velocity, attitude, angular speed). This is designed to be used when e.g an external SLAM system detects a loop-closure and the estimate jumps.
- Global position/attitude estimate from a vision source.
+ Local position/attitude estimate from a vision source.
Timestamp (UNIX time or time since system boot)
- Global X position
- Global Y position
- Global Z position
+ Local X position
+ Local Y position
+ Local Z position
Roll angle
Pitch angle
Yaw angle
diff --git a/minimal/version.h b/minimal/version.h
index 3832bbdc2..e5ab3587c 100644
--- a/minimal/version.h
+++ b/minimal/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 22
diff --git a/slugs/version.h b/slugs/version.h
index 2a44b3737..2c892e6e1 100644
--- a/slugs/version.h
+++ b/slugs/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/standard/version.h b/standard/version.h
index 0229e0cda..bef13d72a 100644
--- a/standard/version.h
+++ b/standard/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/test/version.h b/test/version.h
index 3cc8c8eeb..480e00e3c 100644
--- a/test/version.h
+++ b/test/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 179
diff --git a/uAvionix/version.h b/uAvionix/version.h
index 73d322999..c8d1492b0 100644
--- a/uAvionix/version.h
+++ b/uAvionix/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Oct 07 2019"
+#define MAVLINK_BUILD_DATE "Tue Oct 08 2019"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/mavlink_msg_vision_position_estimate.h b/common/mavlink_msg_vision_position_estimate.h
index d08bd1d39..55846103b 100644
--- a/common/mavlink_msg_vision_position_estimate.h
+++ b/common/mavlink_msg_vision_position_estimate.h
@@ -6,9 +6,9 @@
MAVPACKED(
typedef struct __mavlink_vision_position_estimate_t {
uint64_t usec; /*< [us] Timestamp (UNIX time or time since system boot)*/
- float x; /*< [m] Global X position*/
- float y; /*< [m] Global Y position*/
- float z; /*< [m] Global Z position*/
+ float x; /*< [m] Local X position*/
+ float y; /*< [m] Local Y position*/
+ float z; /*< [m] Local Z position*/
float roll; /*< [rad] Roll angle*/
float pitch; /*< [rad] Pitch angle*/
float yaw; /*< [rad] Yaw angle*/
@@ -66,9 +66,9 @@ typedef struct __mavlink_vision_position_estimate_t {
* @param msg The MAVLink message to compress the data into
*
* @param usec [us] Timestamp (UNIX time or time since system boot)
* @param x [m] Global X position
* @param y [m] Global Y position
* @param z [m] Global Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle
* @param yaw [rad] Yaw angle
@@ -116,9 +116,9 @@ static inline uint16_t mavlink_msg_vision_position_estimate_pack(uint8_t system_
* @param chan The MAVLink channel this message will be sent over
* @param msg The MAVLink message to compress the data into
* @param usec [us] Timestamp (UNIX time or time since system boot)
* @param x [m] Global X position
* @param y [m] Global Y position
* @param z [m] Global Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle
* @param yaw [rad] Yaw angle
@@ -192,9 +192,9 @@ static inline uint16_t mavlink_msg_vision_position_estimate_encode_chan(uint8_t
* @param chan MAVLink channel to send the message
*
* @param usec [us] Timestamp (UNIX time or time since system boot)
* @param x [m] Global X position
* @param y [m] Global Y position
* @param z [m] Global Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle
* @param yaw [rad] Yaw angle
@@ -302,7 +302,7 @@ static inline uint64_t mavlink_msg_vision_position_estimate_get_usec(const mavli
/**
* @brief Get field x from vision_position_estimate message
*
- * @return [m] Global X position
+ * @return [m] Local X position
*/
static inline float mavlink_msg_vision_position_estimate_get_x(const mavlink_message_t* msg)
{
@@ -312,7 +312,7 @@ static inline float mavlink_msg_vision_position_estimate_get_x(const mavlink_mes
/**
* @brief Get field y from vision_position_estimate message
*
- * @return [m] Global Y position
+ * @return [m] Local Y position
*/
static inline float mavlink_msg_vision_position_estimate_get_y(const mavlink_message_t* msg)
{
@@ -322,7 +322,7 @@ static inline float mavlink_msg_vision_position_estimate_get_y(const mavlink_mes
/**
* @brief Get field z from vision_position_estimate message
*
- * @return [m] Global Z position
+ * @return [m] Local Z position
*/
static inline float mavlink_msg_vision_position_estimate_get_z(const mavlink_message_t* msg)
{
@@ -66,9 +66,9 @@ typedef struct __mavlink_vision_position_estimate_t {
*
* @param usec [us] Timestamp (UNIX time or time since system boot)
- * @param x [m] Global X position
- * @param y [m] Global Y position
- * @param z [m] Global Z position
+ * @param x [m] Local X position
+ * @param y [m] Local Y position
+ * @param z [m] Local Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle
@@ -116,9 +116,9 @@ static inline uint16_t mavlink_msg_vision_position_estimate_pack(uint8_t system_
* @param msg The MAVLink message to compress the data into
* @param usec [us] Timestamp (UNIX time or time since system boot)
- * @param x [m] Global X position
- * @param y [m] Global Y position
- * @param z [m] Global Z position
+ * @param x [m] Local X position
+ * @param y [m] Local Y position
+ * @param z [m] Local Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle
@@ -192,9 +192,9 @@ static inline uint16_t mavlink_msg_vision_position_estimate_encode_chan(uint8_t
*
* @param usec [us] Timestamp (UNIX time or time since system boot)
- * @param x [m] Global X position
- * @param y [m] Global Y position
- * @param z [m] Global Z position
+ * @param x [m] Local X position
+ * @param y [m] Local Y position
+ * @param z [m] Local Z position
* @param roll [rad] Roll angle
* @param pitch [rad] Pitch angle